package com.usky.system.service.impl;


import com.google.gson.JsonObject;
import com.usky.common.core.bean.ApiResult;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.system.domain.SysNotice;
import com.usky.system.mapper.SysNoticeMapper;
import com.usky.system.service.ISysNoticeService;
import com.usky.system.service.MceReceiveService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 公告 服务层实现
 * 
 * @author ruoyi
 */
@Service
public class SysNoticeServiceImpl extends AbstractCrudService<SysNoticeMapper, SysNotice> implements ISysNoticeService
{
    @Autowired
    private SysNoticeMapper noticeMapper;

    @Autowired
    private MceReceiveService mceReceiveService;

    /**
     * 查询公告信息
     * 
     * @param noticeId 公告ID
     * @return 公告信息
     */
    @Override
    public SysNotice selectNoticeById(Long noticeId)
    {
        return noticeMapper.selectNoticeById(noticeId);
    }

    /**
     * 查询公告列表
     * 
     * @param notice 公告信息
     * @return 公告集合
     */
    @Override
    public List<SysNotice> selectNoticeList(SysNotice notice)
    {
        return noticeMapper.selectNoticeList(notice);
    }

    /**
     * 新增公告
     * 
     * @param notice 公告信息
     * @return 结果
     */
    @Override
    public int insertNotice(SysNotice notice)
    {
        noticeMapper.insertNotice(notice);
        int insertId = notice.getNoticeId();
        JsonObject jsonObject = new JsonObject();
        jsonObject.addProperty("infoTitle", notice.getNoticeTitle());
        jsonObject.addProperty("infoContent",notice.getNoticeContent());
        jsonObject.addProperty("infoType",1);
        jsonObject.addProperty("id",insertId);
        mceReceiveService.add(jsonObject.toString());
        return insertId;
    }

    /**
     * 修改公告
     * 
     * @param notice 公告信息
     * @return 结果
     */
    @Override
    public int updateNotice(SysNotice notice)
    {
        return noticeMapper.updateNotice(notice);
    }

    /**
     * 删除公告对象
     * 
     * @param noticeId 公告ID
     * @return 结果
     */
    @Override
    public int deleteNoticeById(Long noticeId)
    {
        return noticeMapper.deleteNoticeById(noticeId);
    }

    /**
     * 批量删除公告信息
     * 
     * @param noticeIds 需要删除的公告ID
     * @return 结果
     */
    @Override
    public int deleteNoticeByIds(Long[] noticeIds)
    {
        return noticeMapper.deleteNoticeByIds(noticeIds);
    }
}
